==> dif-database-repository-2.3.11-2-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/AuthorizationServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.IAuthorizationService;
import pt.digitalis.dif.dem.managers.impl.model.dao.IAclDAO;
import pt.digitalis.dif.dem.managers.impl.model.dao.impl.AclDAOImpl;
import pt.digitalis.dif.dem.managers.impl.model.data.Acl;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public class AuthorizationServiceImpl implements IAuthorizationService {

	/**
	 * Obtains a new Acl DAO
	 *
	 * @return A new IAclDAO
	 */
    public IAclDAO getAclDAO() {
    	return new AclDAOImpl();
    }

    /**
     * Obtains a new DataSet for the Acl entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<Acl> getAclDataSet() {
        return new HibernateDataSet<Acl>(Acl.class, new AclDAOImpl(),
                Acl.getPKFieldListAsString());
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == Acl.class)
            return getAclDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(Acl.class.getSimpleName()))
            return getAclDataSet();

        return null;
    }
}

==> dif-database-repository-2.6.1-8-20200421.173538-1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/AuthorizationServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.IAuthorizationService;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IAclDAO;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.impl.AclDAOImpl;
import pt.digitalis.dif.dem.managers.impl.model.data.Acl;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public class AuthorizationServiceImpl implements IAuthorizationService {

	/**
	 * Obtains a new Acl DAO
	 *
	 * @return A new IAclDAO
	 */
    public IAclDAO getAclDAO() {
    	return new AclDAOImpl();
    }

    /**
     * Obtains a new DataSet for the Acl entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<Acl> getAclDataSet() {
        return new HibernateDataSet<Acl>(Acl.class, new AclDAOImpl(),
                Acl.getPKFieldListAsString());
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == Acl.class)
            return getAclDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(Acl.class.getSimpleName()))
            return getAclDataSet();

        return null;
    }
}
